@@ -2,7 +2,7 @@
 # @Author  : llc
 # @Time    : 2021/4/28 11:24
 from http import HTTPStatus
-from typing import Optional
+from typing import Optional, List
 
 from pydantic import BaseModel, Field
 
@@ -39,16 +39,21 @@ security = [
 app.config["VALIDATE_RESPONSE"] = True
 
 
-class Path(BaseModel):
+class BookPath(BaseModel):
     bid: int = Field(..., description='book id')
 
 
-class BookData(BaseModel):
+class BookQuery(BaseModel):
+    age: Optional[int] = Field(None, description='Age')
+    s_list: List[str] = Field(None, alias='s_list[]', description='some array')
+
+
+class BookBody(BaseModel):
     age: Optional[int] = Field(..., ge=2, le=4, description='Age')
     author: str = Field(None, min_length=2, max_length=4, description='Author')
 
 
-class BookDataWithID(BaseModel):
+class BookBodyWithID(BaseModel):
     bid: int = Field(..., description='book id')
     age: Optional[int] = Field(None, ge=2, le=4, description='Age')
     author: str = Field(None, min_length=2, max_length=4, description='Author')
@@ -57,11 +62,11 @@ class BookDataWithID(BaseModel):
 class BookResponse(BaseModel):
     code: int = Field(0, description="Status Code")
     message: str = Field("ok", description="Exception Information")
-    data: Optional[BookDataWithID]
+    data: Optional[BookBodyWithID]
 
 
 @app.get('/book/<int:bid>', tags=[book_tag], responses={"200": BookResponse}, security=security)
-def get_book(path: Path):
+def get_book(path: BookPath):
     """Get book
     Get some book by id, like:
     http://localhost:5000/book/3
@@ -72,36 +77,37 @@ def get_book(path: Path):
 
 
 # set doc_ui False disable openapi UI
-@app.get('/book', doc_ui=False)
-def get_books(query: BookData):
+@app.get('/book', doc_ui=True)
+def get_books(query: BookQuery):
     """get books
     get all books
     """
+    print(query)
     return {
         "code": 0,
         "message": "ok",
         "data": [
-            {"bid": 1, "age": query.age, "author": query.author},
-            {"bid": 2, "age": query.age, "author": query.author}
+            {"bid": 1, "age": query.age, "author": 'a1'},
+            {"bid": 2, "age": query.age, "author": 'a2'}
         ]
     }
 
 
 @app.post('/book', tags=[book_tag], responses={"200": BookResponse})
-def create_book(body: BookData):
+def create_book(body: BookBody):
     print(body)
     return {"code": 0, "message": "ok"}, HTTPStatus.OK
 
 
 @app.put('/book/<int:bid>', tags=[book_tag])
-def update_book(path: Path, body: BookData):
+def update_book(path: BookPath, body: BookBody):
     print(path)
     print(body)
     return {"code": 0, "message": "ok"}
 
 
 @app.delete('/book/<int:bid>', tags=[book_tag], doc_ui=False)
-def delete_book(path: Path):
+def delete_book(path: BookPath):
     print(path)
     return {"code": 0, "message": "ok"}
 
