@@ -4,9 +4,13 @@
 
 
 from .models.file import FileStorage
+from .models.info import Info
+from .models.oauth import OAuthConfig
+from .models.security import HTTPBase, HTTPBearer, OAuth2, APIKey, OpenIdConnect
+from .models.tag import Tag
+from .models.validation_error import UnprocessableEntity
 from .openapi import APIBlueprint
 from .openapi import OpenAPI
-from .plugins import OAuthConfig
 
 print(r"""
   __ _           _                                             _  _____
