@@ -10,12 +10,13 @@ from typing import Optional, List, Dict, Union, Any, Type, Callable, Tuple
 
 from flask import Flask, Blueprint, render_template, request, make_response, current_app
 from pydantic import ValidationError, BaseModel, AnyUrl
+from werkzeug.datastructures import MultiDict
 
 from .markdown import openapi_to_markdown
 from .models import Info, APISpec, Tag, Components
 from .models.common import Reference, ExternalDocumentation
+from .models.oauth import OAuthConfig
 from .models.security import SecurityScheme
-from .plugins import OAuthConfig
 from .utils import _parse_rule, get_operation, get_responses, parse_and_store_tags, parse_parameters, \
     validate_responses_type, parse_method, validate_response
 
@@ -57,12 +58,25 @@ def _do_wrapper(
             path_ = path(**kwargs)
             kwargs_.update({"path": path_})
         if query:
-            query_ = query(**request.args.to_dict() if request.args.to_dict() is not None else {})
+            args = request.args or MultiDict()
+            args_dict = {}
+            for k, v in query.schema().get('properties', {}).items():
+                if v.get('type') == 'array':
+                    args_dict[k] = args.getlist(k)
+                else:
+                    args_dict[k] = args.get(k)
+            query_ = query(**args_dict)
             kwargs_.update({"query": query_})
         if form:
-            req_form = request.form.to_dict()
-            req_form.update(**request.files.to_dict() if request.files.to_dict() is not None else {})
-            form_ = form(**req_form if req_form is not None else {})
+            req_form = request.form or MultiDict()
+            form_dict = {}
+            for k, v in form.schema().get('properties', {}).items():
+                if v.get('type') == 'array':
+                    form_dict[k] = req_form.getlist(k)
+                else:
+                    form_dict[k] = req_form.get(k)
+            form_dict.update(**request.files.to_dict())
+            form_ = form(**form_dict)
             kwargs_.update({"form": form_})
         if body:
             body_ = body(
@@ -96,12 +110,16 @@ class APIBlueprint(Blueprint):
     ):
         """
         Based on Flask Blueprint
-        :param args: Flask Blueprint args
-        :param abp_tags: APIBlueprint tags for every api
-        :param abp_security: APIBlueprint security for every api
-        :param abp_responses: APIBlueprint response model
-        :param doc_ui: add openapi document UI(swagger and redoc). Defaults to True.
-        :param kwargs: Flask Blueprint kwargs
+
+        Arguments:
+            name: The name of the blueprint. Will be prepended to each endpoint name.
+            import_name: The name of the blueprint package, usually
+                         ``__name__``. This helps locate the ``root_path`` for the blueprint.
+            abp_tags: APIBlueprint tags for every api
+            abp_security: APIBlueprint security for every api
+            abp_responses: APIBlueprint response model
+            doc_ui: add openapi document UI(swagger and redoc). Defaults to True.
+            kwargs: Flask Blueprint kwargs
         """
         super(APIBlueprint, self).__init__(name, import_name, **kwargs)
         self.paths = dict()
@@ -180,6 +198,7 @@ class APIBlueprint(Blueprint):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ):
+        """Decorator for rest api, like: app.route(methods=['GET'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui)
@@ -204,6 +223,7 @@ class APIBlueprint(Blueprint):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ):
+        """Decorator for rest api, like: app.route(methods=['POST'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="post")
@@ -228,6 +248,7 @@ class APIBlueprint(Blueprint):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ):
+        """Decorator for rest api, like: app.route(methods=['PUT'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="put")
@@ -252,6 +273,7 @@ class APIBlueprint(Blueprint):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ):
+        """Decorator for rest api, like: app.route(methods=['DELETE'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="delete")
@@ -276,6 +298,7 @@ class APIBlueprint(Blueprint):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ):
+        """Decorator for rest api, like: app.route(methods=['PATCH'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="patch")
@@ -301,17 +324,25 @@ class OpenAPI(Flask):
                  oauth_config: OAuthConfig = None,
                  responses: Dict[str, Type[BaseModel]] = None,
                  doc_ui: bool = True,
+                 docExpansion: str = "list",
                  **kwargs: Any
                  ) -> None:
         """
         Based on Flask. Provide REST api, swagger-ui and redoc.
-        :param import_name: just flask import_name
-        :param info: see https://spec.openapis.org/oas/v3.0.3#info-object
-        :param securitySchemes: see https://spec.openapis.org/oas/v3.0.3#security-scheme-object
-        :param oauth_config: OAuth 2.0 configuration, see https://github.com/swagger-api/swagger-ui/blob/master/docs/usage/oauth2.md
-        :param responses: OpenAPI response model
-        :param doc_ui: add openapi document UI(swagger and redoc). Defaults to True.
-        :param kwargs:
+
+        Arguments:
+            import_name: just flask import_name
+            info: see https://spec.openapis.org/oas/v3.0.3#info-object
+            securitySchemes: see https://spec.openapis.org/oas/v3.0.3#security-scheme-object
+            oauth_config: OAuth 2.0 configuration, see https://github.com/swagger-api/swagger-ui/blob/master/docs/usage/oauth2.md
+            responses: OpenAPI response model
+            doc_ui: add openapi document UI(swagger and redoc). Defaults to True.
+            docExpansion: String=["list"*, "full", "none"].
+                          Controls the default expansion setting for the operations and tags.
+                          It can be 'list' (expands only the tags),
+                         'full' (expands the tags and operations) or 'none' (expands nothing).
+                         see https://github.com/swagger-api/swagger-ui/blob/master/docs/usage/configuration.md
+            kwargs: Flask kwargs
         """
         super(OpenAPI, self).__init__(import_name, **kwargs)
 
@@ -335,11 +366,11 @@ class OpenAPI(Flask):
         self.oauth_config = oauth_config
         if doc_ui:
             self.init_doc()
+        self.docExpansion = docExpansion
 
     def init_doc(self) -> None:
         """
         Provide swagger-ui and redoc
-        :return:
         """
         _here = os.path.dirname(__file__)
         template_folder = os.path.join(_here, 'templates')
@@ -368,6 +399,7 @@ class OpenAPI(Flask):
             view_func=lambda: render_template(
                 "swagger.html",
                 api_doc_url=f'{self.api_name}.json',
+                docExpansion=self.docExpansion,
                 oauth_config=self.oauth_config.dict() if self.oauth_config else None
             )
         )
@@ -483,6 +515,7 @@ class OpenAPI(Flask):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ) -> Callable:
+        """Decorator for rest api, like: app.route(methods=['GET'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui)
@@ -507,6 +540,7 @@ class OpenAPI(Flask):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ) -> Callable:
+        """Decorator for rest api, like: app.route(methods=['POST'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="post")
@@ -531,6 +565,7 @@ class OpenAPI(Flask):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ) -> Callable:
+        """Decorator for rest api, like: app.route(methods=['PUT'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="put")
@@ -555,6 +590,7 @@ class OpenAPI(Flask):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ) -> Callable:
+        """Decorator for rest api, like: app.route(methods=['DELETE'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="delete")
@@ -579,6 +615,7 @@ class OpenAPI(Flask):
             security: List[Dict[str, List[Any]]] = None,
             doc_ui: bool = True
     ) -> Callable:
+        """Decorator for rest api, like: app.route(methods=['PATCH'])"""
         def decorator(func):
             header, cookie, path, query, form, body, _responses = \
                 self._do_decorator(rule, func, tags, responses, security, doc_ui, method="patch")
